var indexSectionsWithContent =
{
  0: "abcdefghijklmnopqrstuvwz~",
  1: "abcdefghijklmnopqrstuvz",
  2: "dv",
  3: "abcdefghijklmnopqrstuvw",
  4: "abcdefghijklmnopqrstuvwz~",
  5: "abcdefghijklmnoprstvw",
  6: "cdefhimnoprstuv",
  7: "abdeflmorsv",
  8: "abcdefhiklmnoprstuv",
  9: "cens",
  10: "bdegnrtv",
  11: "abcdfilmstuv"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Pages"
};

